module.exports = function (ws) {
    var add2 = function (req,res) {
        console.log("call meeee");
        var x = req.params.x;
        var y = req.params.y;
        console.log("add2() called with " + x + " and " + y);
          //req.r.table('apps')
          //.getAll()
          //.run()
          //.then(function(data){
            //  console.log(data);
              //console.log(JSON.stringify(data))
            //  return JSON.stringify(data);
              res.json({name:"ehllo"});
          //});
       // return x + y;
    };

    var sub=function (args){
        console.log(args);
    }

    ws.subscribe("com.test.hello",sub);
    ws.register("com.test.add", add2);
}